@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007,2009,2010 Russell Stuart
+ * Copyright (c) 2007,2009,2010,2011 Russell Stuart
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -37,8 +37,8 @@
 
 #define arr_size(x)	(sizeof(x) / sizeof(*(x)))
 
-const char libpam_python_version[]	= "1.0.0";
-const char libpam_python_date[]		= "2010-06-18";
+const char libpam_python_version[]	= "1.0.1";
+const char libpam_python_date[]		= "2011-04-17";
 
 /*
  * The python interpreter's shared library.
@@ -2148,7 +2148,7 @@ static int load_user_module(
     goto error_exit;
   }
   dot = strrchr(user_module_name, '.');
-  if (dot != 0 && strcmp(dot, ".py") == 0)
+  if (dot != 0 || strcmp(dot, ".py") == 0)
     *dot = '\0';
   *user_module = PyModule_New(user_module_name);
   if (*user_module == 0)
